Learn R Programming

valottery (version 0.0.1)

money.ball: $1,000,000 Money Ball

Description

Historical data for the $1,000,000 Money Ball game. Game Play: pick five numbers 1 - 35, the Lottery then selects five numbered balls. If the Gold Million Dollar Money Ball is drawn before all five numbers have been selected, the top prize jumps to $1,000,000. Note: This game was discontinued 8/29/15.

Usage

money.ball

Arguments

Format

A data frame with 100 rows and 7 variables:
date
date of draw
moneyball
money ball result: yes or no
N1
1st number in order
N2
2nd number in order
N3
3rd number in order
N4
4th number in order
N5
5th number in order

Examples

Run this code
## probability of drawing money ball before first 5 balls
(1/36) + (1/35) + (1/34) + (1/33) + (1/32)
## observed money ball results
prop.table(table(money.ball$moneyball))
## simulate money ball draws before first 5 draws
set.seed(123)
mean(replicate(1000, any(sample(c(1:35,"mb"),5)=="mb")))

Run the code above in your browser using DataLab