Learn R Programming

valottery (version 0.0.1)

power.ball: Power Ball

Description

Historical data for the Power Ball game. Game play: Pick five different numbers from 1 through 59; then select one Powerball number from 1 through 35.

Usage

power.ball

Arguments

Format

A data frame with 582 rows and 7 variables:
date
date of draw
powerball
powerball result
N1
1st number in order
N2
2nd number in order
N3
3rd number in order
N4
4th number in order
N5
5th number in order

Examples

Run this code
## According to game rules, the powerball is numbered 1 - 35,
## but apparently there were times when it went up to 39
i <- power.ball$powerball > 35
any(i)
sum(i)
power.ball$powerball[i]

Run the code above in your browser using DataLab